@@ -51,8 +51,8 @@ NNS.FSD <- function(x, y, type = "discrete", plot = TRUE){
 
 
   plot(Combined_sort, LPM_x_sort, type = "l", lwd = 3,col = "red", main = "FSD", ylab = "Probability of Cumulative Distribution", ylim = c(0, 1))
-  lines(Combined_sort, LPM_y_sort, type = "l", lwd = 3,col = "blue")
-  legend("topleft", c("X", "Y"), lwd = 10, col = c("red", "blue"))
+  lines(Combined_sort, LPM_y_sort, type = "l", lwd = 3,col = "steelblue")
+  legend("topleft", c("X", "Y"), lwd = 10, col = c("red", "steelblue"))
 
   ## Verification of ***0 instances*** of CDFx > CDFy, and conversely of CDFy > CDFx
   ifelse (!x.fsd.y && min(x) >= min(y) && !identical(LPM_x_sort, LPM_y_sort),
